<template>
  <div class="app-container">
<!--    <el-form :model="queryParams" @submit.native.prevent ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">-->
<!--      <el-form-item label="编排单号" prop="arrangeCode">-->
<!--        <el-input-->
<!--          v-model="queryParams.arrangeCode"-->
<!--         -->
<!--          clearable-->
<!--          @keyup.enter.native="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item :label="$t('role.idx')" prop="arrangeSort">-->
<!--        <el-input-->
<!--          v-model="queryParams.arrangeSort"-->
<!--         -->
<!--          clearable-->
<!--          @keyup.enter.native="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="生产工单" prop="workorderId">-->
<!--        <el-input-->
<!--          v-model="queryParams.workorderId"-->
<!--         -->
<!--          clearable-->
<!--          @keyup.enter.native="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="生产工单编号" prop="workorderCode">-->
<!--        <el-input-->
<!--          v-model="queryParams.workorderCode"-->
<!--         -->
<!--          clearable-->
<!--          @keyup.enter.native="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item>-->
<!--        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">{{ $t('common.search') }}</el-button>-->
<!--        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">{{ $t('common.reset') }}</el-button>-->
<!--      </el-form-item>-->
<!--    </el-form>-->

    <el-row v-if="showBtn" :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-plus"
          size="mini"
          :disabled="multiple"
          @click="handleCombination"
          v-hasPermi="['pro:combination:add']"
        >{{$t('拆分为新编排单')}}</el-button>
      </el-col>
      <el-col v-if="addBtn" :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['pro:arrange:add']"
        >{{$t('新增')}}</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['pro:arrange:edit']"
        >{{$t('修改')}}</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['pro:arrange:remove']"
        >{{$t('删除')}}</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['pro:arrange:export']"
        >{{$t('导出')}}</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="arrangeList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center"/>
      <el-table-column :label="$t('编排单号')" align="center" prop="arrangeCode"/>
      <el-table-column :label="$t('role.idx')" width="150" align="center" prop="arrangeSort" >
        <template slot-scope="scope">
          <el-input-number v-model="scope.row.arrangeSort" @change="handleChangeSort(scope.row)" :min="0"
                           style="width: 140px"
                           :label="$t('role.idx')"></el-input-number>
        </template>
      </el-table-column>
      <el-table-column :label="$t('生产工单')" align="center" prop="workorderCode"/>
      <el-table-column v-if="showBtn" :label="$t('common.option')" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['pro:arrange:edit']"
          >{{$t('修改')}}</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['pro:arrange:remove']"
          >{{$t('删除')}}</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改生产编排单对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="800px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-form-item :label="$t('生产工单编号')" prop="workorderCode">
          {{ form.workorderCode }}
          <!-- <el-input v-model="form.workorderCode"/> -->
        </el-form-item>
        <el-form-item :label="$t('编排单号')" prop="arrangeCode">
          <el-input v-model="form.arrangeCode"/>
        </el-form-item>
        <el-form-item :label="$t('role.idx')" prop="arrangeSort">
          <!-- <el-input v-model="form.arrangeSort"/> -->
          <el-input-number v-model="form.arrangeSort" :min="0"
            :label="$t('role.idx')"></el-input-number>
        </el-form-item>
        <!-- <el-form-item label="生产工单" prop="workorderId">
          <el-input v-model="form.workorderId"/>
        </el-form-item> -->
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">{{ $t('common.confirm') }}</el-button>
        <el-button @click="cancel">{{ $t('common.cancel') }}</el-button>
      </div>
    </el-dialog>


    <el-dialog :title="$t('追加编排单')" :visible.sync="arrangeOpen" width="800px" append-to-body @close="getList">
      <choose-workorder-for-arrange v-if="arrangeOpen" :arrangeCode="arrangeCode"></choose-workorder-for-arrange>
    </el-dialog>
  </div>
</template>

<script>


import {listArrange, getArrange, delArrange, addArrange, updateArrange} from "@/api/mes/pro/arrange";
import {updateCombination} from "@/api/mes/pro/combination";
import ChooseWorkorderForArrange from "@/views/mes/pro/arrange/chooseWorkorderForArrange.vue";
import {splitArrange} from "@/api/mes/pro/arrange";
export default {
  name: "ArrangeInfo",
  components: {ChooseWorkorderForArrange},
  props: {
    groupCode: {
      type: String,
      default: null
    },
    arrangeCode: {
      type: String,
      default: null
    },
    addBtn: {
      type: Boolean,
      default: true
    },
    showBtn: {
      type: Boolean,
      default: true
    }
  },
  data() {
    return {
      // 遮罩层
      loading: true,
      arrangeOpen :false,

      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 生产编排单表格数据
      arrangeList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        arrangeCode: null,
        groupCode:null,
        arrangeSort: null,
        workorderId: null,
        workorderCode: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        arrangeCode: [
          {required: true, message: this.$t('编排单号不能为空'), trigger: "blur"}
        ], arrangeSort: [
          {required: true, message: this.$t('序号不能为空'), trigger: "blur"}
        ],
      }
    };
  },
  created() {
    // this.getList();
  },
  watch: {
    groupCode: {
      handler(newVal, oldVal) {
        if (newVal) {
          this.queryParams.groupCode = newVal;
          this.queryParams.arrangeCode = null;
          this.getList();
        }
      },
      immediate: true
    },
    arrangeCode: {
      handler(newVal, oldVal) {
        if (newVal) {
          this.queryParams.arrangeCode = newVal;
          this.queryParams.groupCode = null;
          this.getList();
        }
      },
      immediate: true
    },

  },
  methods: {
    handleCombination() {
      // row.arrangeId
      console.log(this.ids, 'this.ids')
      const params = new FormData()
      this.ids.forEach(item => {
        params.append('arrangeIds', item)
      })
      splitArrange(params).then(response => {
        if (response.code === 200) {
           this.getList()
        }
      });
    },
    handleChangeSort(item) {
      updateArrange({...item}).then(response => {
        if (response.code === 200) {
           this.getList()
        }
      });
    },
    /** 查询生产编排单列表 */
    getList() {
      this.loading = true;
      listArrange(this.queryParams).then(response => {
        this.arrangeList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        arrangeId: null, arrangeCode: null, arrangeSort: null, workorderId: null, workorderCode: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.arrangeId)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.arrangeOpen = true;
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const arrangeId = row.arrangeId || this.ids
      getArrange(arrangeId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = this.$t('修改生产编排单');
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.arrangeId != null) {
            updateArrange(this.form).then(response => {
              this.$modal.msgSuccess(this.$t('common.edit_success'));
              this.open = false;
              this.getList();
            });
          } else {
            addArrange(this.form).then(response => {
              this.$modal.msgSuccess(this.$t('common.add_success'));
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const arrangeIds = row.arrangeId || this.ids;
      let workorderCode = row.workorderCode
      if(!row || !workorderCode) {
        const finditem = this.arrangeList.find(v=>v.arrangeId === this.ids[0])
        if(finditem) workorderCode = finditem.workorderCode
      }
      this.$modal.confirm(this.$t('common.confirm_del_data')).then(function () {
        return delArrange(arrangeIds);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess(this.$t('common.del_success'));
      }).catch(() => {
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('pro/arrange/export', {
        ...this.queryParams
      }, `arrange_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
